.. _all-salt.renderers:

==============================
Full list of builtin renderers
==============================

.. currentmodule:: salt.renderers

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    json_jinja
    json_mako
    yaml_jinja
    yaml_mako
    py
